*********
Changelog
*********

v1.1.3 (2024-12-21)
===================
- Made rich text evaluation more robust for complex results.


v1.1.2 (2024-12-20)
===================
- Bumped required elementpath version to fix bug #6.


v1.1.1 (2024-11-27)
===================

Changed
-------
- Updated is_valid comment in the API.


v1.1.0 (2024-11-27)
===================

Fixed
-----
- Fixes github bug #5. The reporting of the is_valid method was reversed with regard to assert/report. Also fixed the documentation regarding the is_valid function.


v1.0.3 (2024-10-29)
===================

Changed
-------
- Updated elementpath dependency version.


v1.0.2 (2024-10-18)
===================

Changed
-------
- Updated lxml dependency from 5.1.0 to 5.2.1.
- Updated readme to include supported Python version and other textual changes.


v1.0.1 (2024-09-24)
===================
- Upgraded to elementpath==4.5.0
- fixed email address in info blocks.

v1.0.0 (2024-08-23)
===================
First complete version of PySchematron. See the readme for the functionality and limitations.

v0.1.0 (2022-09-10)
===================
First version.
